/**
 * Copyright (C) 2007-2012 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>

#include <gtk/gtk.h>

gchar *locale = NULL;
GtkListStore *store;
GtkWidget *combo;

const struct lang {
    const gchar *locale;
    const gchar *kbd;
    const gchar *desc;
} langs[] =
{
    { "en_US.UTF-8", "us", "English" },
    { "fr_FR.UTF-8", "fr", "Français" },
    { NULL }
};

void
get ()
{
    const gchar *cmd;
    gchar *err, *out;
    gint status;

    cmd = "sh " LIBEXECDIR "/mini_get_lang.sh";
    g_spawn_command_line_sync (cmd, &out, &err, &status, NULL);

    locale = out;

    g_free (err);
}

void
set ()
{
    gchar *cmd;
    gchar *err, *out;
    gint status;
    GtkTreeIter iter;
    gint i;

    gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter);
    gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 0, &i, -1);

    cmd = g_strdup_printf ("sh " LIBEXECDIR "mini_set_lang.sh %s %s",
                           langs[i].locale, langs[i].kbd);
    g_spawn_command_line_sync (cmd, &out, &err, &status, NULL);

    g_free (err);
    g_free (out);
    g_free (cmd);
}

int
main (gint argc, gchar **argv)
{
    GtkWidget *d, *content_area;
    GtkWidget *label;
    GtkCellRenderer *renderer;
    GtkTreeIter iter;
    int i = 0;
    gboolean done = FALSE;

    gtk_init (&argc, &argv);

    if (0 != getuid ())
    {
        d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                GTK_MESSAGE_WARNING,
                                GTK_BUTTONS_OK,
                                "You don't appear to be root. Exiting.");
        gtk_dialog_run (GTK_DIALOG (d));
        exit (1);
    }

    get ();

    d = gtk_dialog_new_with_buttons ("Language selection", NULL, 0,
                                     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
    content_area = gtk_dialog_get_content_area (GTK_DIALOG (d));

    label = gtk_label_new ("Select your language:");
    gtk_widget_show (label);
    gtk_box_pack_start (GTK_BOX (content_area), label, FALSE, FALSE, 6);

    store = gtk_list_store_new (2, G_TYPE_INT, G_TYPE_STRING);

    combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
    renderer = gtk_cell_renderer_text_new ();
    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
    gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo), renderer,
                                   "text", 1);
    gtk_widget_show (combo);
    gtk_box_pack_start (GTK_BOX (content_area), combo, FALSE, FALSE, 6);

    for (i=0;i<2;i++)
    {
        gtk_list_store_append (store, &iter);
        gtk_list_store_set (store, &iter, 0, i,
                                          1, langs[i].desc,
                                          -1);
        if (g_strcmp0 (langs[i].locale, locale) == 0)
        {
            gtk_combo_box_set_active (GTK_COMBO_BOX (combo), i);
            done = TRUE;
        }
    }
    if (!done)
        gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);


    if (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_ACCEPT)
    {
        const gchar *cmd;
        gchar *out, *err;
        gint status;

        cmd = "sh " LIBEXECDIR "/mini_set_startup.sh";
        g_spawn_command_line_sync (cmd, &out, &err, &status, NULL);
        g_free (out);
        g_free (err);

        set ();
    }

    return 0;
}
